#
# spec file for package python-mongoengine
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-mongoengine
Version:        0.29.1
Release:        1.1
Summary:        Python Object-Document Mapper for working with MongoDB
License:        MIT
Group:          Development/Languages/Python
URL:            http://mongoengine.org/
Source:         https://github.com/MongoEngine/mongoengine/archive/v%{version}.tar.gz
BuildRequires:  %{python_module blinker}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pymongo >= 3.9}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-blinker
Requires:       python-pymongo >= 3.9
Suggests:       python-python-dateutil
BuildArch:      noarch
%python_subpackages

%description
MongoEngine is an ORM-like layer on top of PyMongo.
MongoEngine is a Python Object-Document Mapper for working with MongoDB
built on top of PyMongo.

%prep
%setup -q -n mongoengine-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
rm -v tests/test_connection.py
# o/opytest

%files %{python_files}
%doc AUTHORS README.rst
%license LICENSE
%{python_sitelib}/mongoengine
%{python_sitelib}/mongoengine-%{version}.dist-info

%changelog
* Thu Nov 14 2024 Dirk Müller <dmueller@suse.com>
- update to 0.29.1:
  * Add support for freshly released pymongo 4.9 #2849
  * Fix weakref in EmbeddedDocumentListField (causing brief mem
    leak in certain circumstances) #2827
  * Fix pillow deprecation warning related with LANCZOS filter
    [#2824]
  * Allow gt/gte/lt/lte/ne operators to be used with a list as
    value on ListField #2813
  * Switch tox to use pytest instead of legacy python setup.py
    test #2804
  * Add support for timeseries collection #2661
  * Add support in tests for MongoDB 7.0, pymongo 4.7 and pymongo
    4.8 in the CI #2826
  * Add support for array_filters in Queryset.modify #2811
  * Integrate a docker-compose setup for local testing #2555
  * improve ReferenceField wrong usage detection
  * Fix no_dereference thread-safetyness #2830
  * BREAKING CHANGE: max_length in ListField is now keyword only
    on ListField signature
  * BREAKING CHANGE: Force field argument of ListField/DictField
    to be a field instance (e.g ListField(StringField()) instead
    of ListField(StringField)
* Tue Mar 19 2024 Dirk Müller <dmueller@suse.com>
- update to 0.28.2:
  * Fix typing import incompatible with Pymongo 3.7
  * Fix bug related with recent updates to no_dereference context
    manager #2799
  * Fix for uuidRepresentation not read when provided in URI #2741
  * Add option to user array_filters
  * Fix combination of __raw__ and mongoengine syntax #2773
  * Add tests against MongoDB 6.0 and MongoDB 7.0 in the pipeline
  * Fix validate() not being called when inheritance is used in
    EmbeddedDocument and validate is overriden #2784
  * Add support for readPreferenceTags in connection parameters
  * Use estimated_documents_count OR documents_count when count
    is called, based on the query #2529
  * Fix no_dereference context manager which wasn't turning off
    auto-dereferencing correctly in some cases #2788
  * BREAKING CHANGE: no_dereference context manager no longer
    returns the class in __enter__ #2788
    as it was useless and making it look like it was returning
    a different class although it was the same.
  * Added __raw__ to :meth:`~mongoengine.Queryset.order_by()` to
    allow to provide raw pymongo 'sort' argument and get around
    some of the limitations #2783
  * Add `text_score` argument on mongoengine.Document.search_text()
    to allow text_score computation to be turned off
    as it interfere with natural returned documents order #2759
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 0.27.0:
  * Update uuidRepresentation warnings with "unspecified" as the
    future default (instead of 'standard' previously advertised)
    [#2739]
  * Added `mongo_client_class` optional parameter to connect() to
    allow to use an alternative mongo client than
    pymongo.MongoClient.
  * Fix DictField that always gets marked as changed #2606
  * fix for Queryset.none() that has no effect on
    update/aggregate / first #2669
  * Changes in 0.26.0
  * BREAKING CHANGE: Improved the performance of
    :meth:`~mongoengine.Document.save()`
    by removing the call to
    :meth:`~mongoengine.Document.ensure_indexes` unless
    ``meta['auto_create_index_on_save']`` is set to True. With
    the default settings, Document indexes will still be created
    on the fly, during the first usage of the collection
    (query, insert, etc), they will just not be re-created
    whenever .save() is called.
  * BREAKING CHANGE: remove deprecated method ``ensure_index``
    (replaced by ``create_index`` long time ago).
  * Addition of Decimal128Field:
    :class:`~mongoengine.fields.Decimal128Field` for accurate
    representation of Decimals (much better than the legacy field
    DecimalField).
  * BREAKING CHANGE: When using ListField(EnumField) or
    DictField(EnumField), the values weren't always cast into the
    Enum
  * BREAKING CHANGE (bugfix) Querying ObjectIdField or
    ComplexDateTimeField with None no longer raise a
    ValidationError
  * Allow updating a field that has an operator name e.g. "type"
    with .update(set__type="foo"). It was raising an error
    previously. #2595
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.25.0:
  * Support MONGODB-AWS authentication mechanism (with
    `authmechanismproperties`) #2507
  * Turning off dereferencing for the results of distinct query. #2663
  * Add tests against Mongo 5.0 in pipeline
  * Drop support for Python 3.6 (EOL)
  * Bug fix support for PyMongo>=4 to fix "pymongo.errors.InvalidOperation:
    Cannot use MongoClient after close"
  errors. #2627
  * Bug fix regarding uuidRepresentation that was case sensitive #2650
* Fri Jun 10 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- update to 0.24.1:
  * Allow pymongo<5.0 to be pulled
  * Don't use deprecated property for emptiness check in queryset base #2633
* Mon Mar  7 2022 Dirk Müller <dmueller@suse.com>
- update to 0.24.0:
  * EnumField improvements: now ``choices`` limits the values of an enum to allow
  * Fix bug that prevented instance queryset from using custom queryset_class #2589
  * Fix deepcopy of EmbeddedDocument #2202
  * Introduce a base exception class for MongoEngine exceptions (MongoEngineException).
    Note that this doesn't concern the pymongo errors #2515
  * Fix error when using precision=0 with DecimalField #2535
  * Add support for regex and whole word text search query #2568
  * Add support for update aggregation pipeline #2578
  * BREAKING CHANGE: Updates to support pymongo 4.0. Where possible deprecated
    functionality has been migrated, but additional care should be taken when
    migrating to pymongo 4.0 as existing code may have been using deprecated
    features which have now been removed #2614.
    For the pymongo migration guide see:
    https://pymongo.readthedocs.io/en/stable/migrate-to-pymongo4.html.
    In addition to the changes in the migration guide, the following is a high
    level overview of the changes made to MongoEngine when using pymongo 4.0:
  - limited support of geohaystack indexes has been removed
  - ``QuerySet.map_reduce`` has been migrated from ``Collection.map_reduce``
    and ``Collection.inline_map_reduce`` to use
    ``db.command({mapReduce: ..., ...})`` and support between the two may need
    additional verification.
  - UUIDs are encoded with the ``pythonLegacy`` encoding by default instead of
    the newer and cross platform ``standard`` encoding. Existing UUIDs will
    need to be migrated before changing the encoding, and this should be done
    explicitly by the user rather than switching to a new default by
    MongoEngine. This default will change at a later date, but to allow
    specifying and then migrating to the new format a default ``json_options``
    has been provided.
  - ``Queryset.count`` has been using ``Collection.count_documents`` and
    transparently falling back to ``Collection.count`` when using features that
    are not supported by ``Collection.count_documents``. ``Collection.count``
    has been removed and no automatic fallback is possible. The migration guide
    documents the extended functionality which is no longer supported. Rewrite
    the unsupported queries or fetch the whole result set and perform the count
    locally.
  * Bug fix: ignore LazyReferenceFields when clearing _changed_fields #2484
  * Improve connection doc #2481
  * Bugfix: manually setting SequenceField in DynamicDocument doesn't increment the counter #2471
  * Add MongoDB 4.2 and 4.4 to CI
  * Add support for allowDiskUse on querysets #2468
  * Declare that Py3.5 is not supported in package metadata #2449
  * Moved CI from Travis to Github-Actions
  * Fix LazyReferenceField dereferencing in embedded documents #2426
  * Fix regarding the recent use of Cursor.__spec in .count() that was interfering with mongomock #2425
  * Drop support for Python 3.5 by introducing f-strings in the codebase
  * Bug fix in DynamicDocument which is not parsing known fields in constructor like Document do #2412
  * When using pymongo >= 3.7, make use of Collection.count_documents instead of Collection.count
    and Cursor.count that got deprecated in pymongo >= 3.7.
    This should have a negative impact on performance of count see Issue #2219
  * Fix a bug that made the queryset drop the read_preference after clone().
  * Remove Py3.5 from CI as it reached EOL and add Python 3.9
  * Fix some issues related with db_field/field conflict in constructor #2414
  * BREAKING CHANGE: Fix the behavior of Doc.objects.limit(0) which should return all documents (similar to mongodb) #2311
  * Bug fix in ListField when updating the first item, it was saving the whole list, instead of
    just replacing the first item (as usually done when updating 1 item of the list) #2392
  * Add EnumField: ``mongoengine.fields.EnumField``
  * Refactoring - Remove useless code related to Document.__only_fields and Queryset.only_fields
  * Fix query transformation regarding special operators #2365
  * Bug Fix: Document.save() fails when shard_key is not _id #2154
  * Fix error when setting a string as a ComplexDateTimeField #2253
  * Bump development Status classifier to Production/Stable #2232
  * Improve Queryset.get to avoid confusing MultipleObjectsReturned message in case multiple match are found #630
  * Fixed a bug causing inaccurate query results, while combining ``__raw__`` and regular filters for the same field #2264
  * Add support for the `elemMatch` projection operator in .fields() (e.g BlogPost.objects.fields(elemMatch__comments="test")) #2267
  * DictField validate failed without default connection (bug introduced in 0.19.0) #2239
  * Remove methods that were deprecated years ago:
  - name parameter in Field constructor e.g `StringField(name="...")`, was replaced by db_field
  - Queryset.slave_okay() was deprecated since pymongo3
  - dropDups was dropped with MongoDB3
  - ``Queryset._ensure_indexes`` and ``Queryset.ensure_indexes``, the right method to use is ``Document.ensure_indexes``
  * Added pre-commit for development/CI #2212
  * Renamed requirements-lint.txt to requirements-dev.txt #2212
  * Support for setting ReadConcern #2255
* Tue Mar 31 2020 pgajdos@suse.com
- version update to 0.19.1
  * lot of changes, see
    https://github.com/MongoEngine/mongoengine/blob/master/docs/changelog.rst
- python3 package only (python-Pillow)
- deleted patches
  - fix-requirements.patch (upstreamed)
* Wed Oct 24 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid repetition name in summary.
* Fri Sep 21 2018 Antonio Larrosa <alarrosa@suse.com> - 0.15.3
- Initial release of python-mongoengine 0.15.3
- Add fix-requirements.patch to not force a specific version of python-coverage
